@@ -1,5 +1,5 @@
 """
-``Implementation`` of the h-measure for classification evaluation
+cvextend extends sklearn's model_selection module.
 """
 # Based on NiLearn package
 # License: simplified BSD
@@ -21,4 +21,4 @@
 # 'X.Y.dev0' is the canonical version of 'X.Y.dev'
 #
 
-__version__ = 'v0.2.1'
+__version__ = 'v0.2.2'
