@@ -8,7 +8,6 @@ to use and report
 import collections.abc
 
 from sklearn.metrics import accuracy_score, f1_score, make_scorer
-from sklearn.metrics.scorer import _BaseScorer
 
 _DEFAULT_SCORE_SELECTION = [{'score_name': 'Accuracy', 'score_key': 'rank_test_Accuracy',
                              'score_criteria': 'min', 'scorer': make_scorer(accuracy_score)},
@@ -79,7 +78,7 @@ class ScoreGrid:
         {
             # scorer object itself
             'name': 'scorer',
-            'type': _BaseScorer
+            'type': collections.abc.Callable
         }]
 
     def __init__(self, score_selection=_DEFAULT_SCORE_SELECTION):
